@@ -1,4 +1,5 @@
 import datetime
+import json
 from argparse import ArgumentParser, Namespace, _SubParsersAction
 from pprint import pformat
 from typing import Any, List, Optional, Union
@@ -54,10 +55,18 @@ class CliApiCommand:
 def select_profile(cli: base_media.BaseCliMediaApi) -> int:
     res = cli.get_quality_profiles()
     for profile in res:
-        qualities = ",".join([qual["quality"]["name"] for qual in profile["items"] if qual["allowed"]])
+        qualities = []
+        for qual in profile["items"]:
+            if qual["allowed"]:
+                # Quality items
+                if "quality" in qual:
+                    qualities.append(qual["quality"]["name"])
+                # Quality groups
+                elif "name" in qual:
+                    qualities.append(qual["name"])
         print(f"[{profile['id']}]: {profile['name']} ({qualities})")
     profile_id = input(f"Profile id to use (1-{len(res)}):")
-    if profile_id.isdigit() and int(profile_id) <= len(res):
+    if profile_id.isdigit():
         return int(profile_id)
     else:
         raise Exception("Invalid profile selection: {}")
@@ -171,6 +180,21 @@ class CliWantedCommand(CliCommand):
         print(f"Result:\n{res}")
 
 
+class CliStatusCommand(CliCommand):
+    name = "status"
+    description = "Get status of 1 or all currently running commands"
+
+    def configure_args(self, cmd_subparser: _SubParsersAction) -> ArgumentParser:
+        cmd_parser = super().configure_args(cmd_subparser)
+        cmd_parser.add_argument("--id", "-i", help="command ID", type=int, default=None)
+        return cmd_parser
+
+    def run(self, cli: base_media.BaseCliMediaApi, args: Namespace) -> None:
+        super().run(cli, args)
+        res = cli.get_command(args.id)
+        print(f"Result: {json.dumps(res)}\n")
+
+
 ##############################################
 ########## radarr specific commands ##########
 ##############################################
@@ -219,7 +243,7 @@ class CliGetRefreshMovieCommand(CliCommand):
     def run(self, cli: radarr.RadarrCli, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.refresh_movie(args.mid)
-        print(f"Result: {res}\n")
+        print(f"Result: {json.dumps(res)}\n")
 
 
 class CliGetRescanMovieCommand(CliCommand):
@@ -234,7 +258,7 @@ class CliGetRescanMovieCommand(CliCommand):
     def run(self, cli: radarr.RadarrCli, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.rescan_movie(args.mid)
-        print(f"Result: {res}\n")
+        print(f"Result: {json.dumps(res)}\n")
 
 
 class CliAddMovieCommand(CliCommand):
@@ -317,7 +341,7 @@ class CliGetRefreshSerieCommand(CliCommand):
     def run(self, cli: sonarr.SonarrCli, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.refresh_serie(args.sid)
-        print(f"Result: {res}\n")
+        print(f"Result:\n{json.dumps(res)}\n")
 
 
 class CliGetRescanSerieCommand(CliCommand):
@@ -332,7 +356,7 @@ class CliGetRescanSerieCommand(CliCommand):
     def run(self, cli: sonarr.SonarrCli, args: Namespace) -> None:
         super().run(cli, args)
         res = cli.rescan_serie(args.sid)
-        print(f"Result: {res}\n")
+        print(f"Result: {json.dumps(res)}\n")
 
 
 class CliAddSerieCommand(CliCommand):
@@ -436,6 +460,7 @@ CLI_LIST: List[CliApiCommand] = [
             CliGetCalendarCommand(),
             CliDeleteQueueCommand(),
             CliWantedCommand(),
+            CliStatusCommand(),
         ],
     ),
     CliApiCommand(
@@ -454,6 +479,7 @@ CLI_LIST: List[CliApiCommand] = [
             CliGetCalendarCommand(),
             CliDeleteQueueCommand(),
             CliWantedCommand(),
+            CliStatusCommand(),
         ],
     ),
 ]
